<?php

// Edit this file to your liking

// Title your viewer
$TITLE = "Pictor";

// Add a license footer to your pages
//$LICENSE = "All images are Copyright (C) 2000-2010 Your Name &lt;yourname@example.com&gt;";
//$LICENSE = "All images are CC-by-SA Your Name &lt;yourname@example.com&gt;";

// Create an array of albums to seed the random image generator
$RAND_ALBUMS = array();

// Choose a password to edit picture descriptions
//$EDIT_PW = "s0me_passw0rd";

// Set the default columns
$ALBUM_COLUMNS = 6;
$THUMB_COLUMNS = 4;

// Set the default width, should be one of [160, 400, 640, 800, 1024, 1920]
$DEFAULT_WIDTH = 800;

?>
